@@ -22,15 +22,3 @@
 
 #undef HAVE_SETEUID
 #undef HAVE_SETREUID
-
-#undef HAVE_OPENPTY
-#undef HAVE_LOGIN_TTY
-#undef HAVE_SENDMSG
-
-/* Defined, if there is struct lastlog */
-#undef HAVE_LASTLOG
-
-/* define if needed to include sa_len member in struct sockaddr */
-#undef _SOCKADDR_LEN
-
-#undef HAVE_LIBUTIL
