@@ -37,7 +37,7 @@
 #include <libzvt/libzvt.h>
 
 static void zvt_background_set(ZvtTerm *term);
-static gboolean zvt_configure_window(GtkWidget *widget, GdkEventConfigure *event, ZvtTerm *term);
+static void zvt_configure_window(GtkWidget *widget, GdkEventConfigure *event, ZvtTerm *term);
 static void zvt_background_set_translate(ZvtTerm *term);
 
 #define d(x)
@@ -73,7 +73,7 @@ pixmap_from_atom(GdkWindow *win, GdkAtom pmap)
     }
     g_free(data);
   } else {
-    g_warning("Cannot get window property %ld\n", gdk_x11_atom_to_xatom (pmap));
+    g_warning("Cannot get window property %ld\n", pmap);
   }
   gdk_error_trap_pop();
 
@@ -169,8 +169,8 @@ zvt_filter_prop_change(GdkXEvent *_xevent, GdkEvent *event, void *data)
 
     a = (struct _watchatom *)w->watchlist.head;
     while (a->next) {
-      if (gdk_x11_atom_to_xatom (a->atom) == xevent->xproperty.atom) {
-	d(printf("atom %ld has changed\n", gdk_x11_atom_to_xatom (a->atom)));
+      if (a->atom == xevent->xproperty.atom) {
+	d(printf("atom %ld has changed\n", a->atom));
 	a->atom_changed(a->atom, xevent->xproperty.state, a->data);
       }
       a = a->next;
@@ -782,7 +782,7 @@ zvt_background_set_translate(ZvtTerm *term)
  * If we configure window, work out if we have to reload the background
  * image, etc.
  */
-static gboolean
+static void
 zvt_configure_window(GtkWidget *widget, GdkEventConfigure *event, ZvtTerm *term)
 {
   struct _zvtprivate *zp = _ZVT_PRIVATE(term);
@@ -827,7 +827,5 @@ zvt_configure_window(GtkWidget *widget, GdkEventConfigure *event, ZvtTerm *term)
   }
 
   d(printf("we moved/sized\n"));
-
-  return FALSE;
 }
 
