@@ -1273,7 +1273,6 @@ void vt_draw_selection(struct _vtx *vx)
   vx->selendyold = vx->selendy;
   vx->selstartxold = vx->selstartx;
   vx->selstartyold = vx->selstarty;
-  vx->selection_changed (vx->vt.user_data);
 }
 
 /*
@@ -1311,10 +1310,6 @@ dummy_cursor_state(void *user_data, int state)
 {
   return 0;
 }
-static void
-dummy_selection_changed (void *user_data)
-{
-}
 
 static struct vt_line *copy_line(struct vt_line *l)
 {
@@ -1437,7 +1432,7 @@ void vt_getmatches(struct _vtx *vx)
   struct vt_line *wn, *nn, *sol, *ssol;
   int lineno=0, lineskip=0, solineno;
   int c;
-  int matchoffset;		/* for lines which span multiple lines */
+  int matchoffset, smatchoffset;		/* for lines which span multiple lines */
   struct vt_magic_match *mw, *mn;
 
   /* blow away the current 'magic blocks' */
@@ -1673,7 +1668,6 @@ struct _vtx *vtx_new(int width, int height, void *user_data)
   vx->scroll_area = dummy_scroll_area;
   vx->draw_text = dummy_draw_text;
   vx->cursor_state = dummy_cursor_state;
-  vx->selection_changed = dummy_selection_changed;
 
   /* other parameters initialised to 0 by calloc */
   vx->vt.user_data = user_data;
