@@ -1090,7 +1090,7 @@ vt_setmode(struct vt_em *vt, int on)
 	  vt->mode |= VTMODE_BLANK_CURSOR;
 	break;
       case 1047:		/* clear the screen if coming from the alt screen */
-	if (on==0 && (vt->mode&VTMODE_ALTSCREEN))
+	if (on==0 && (vt->mode&&VTMODE_ALTSCREEN))
 	  vt_clear_lines(vt, 0, vt->height);
 	/* falls through */
       case 47:
@@ -1342,8 +1342,7 @@ vt_set_text(struct vt_em *vt)
 {
   char *p;
   int i;
-  char *utf8;
-  
+
   if (vt->change_my_name) {
     p = strchr(vt->arg.txt.args_mem, ';');
     if (p) {
@@ -1369,43 +1368,8 @@ vt_set_text(struct vt_em *vt)
       default:			/* dont care, piss off */
 	return;
       }
-
-      /* XPROPERTY sets an XA_STRING in gnome-terminal and must
-       * therefore be Latin-1 unless gnome-terminal is on crack.
-       * We'll assume the title/iconname are in locale encoding, since
-       * AFAIK they aren't tagged for encoding. xterm seems to treat
-       * them as locale encoding.
-       */
-
-      if (i == VTTITLE_XPROPERTY)
-        {
-          const char *s;
-          GString *str;
-
-          str = g_string_new ("");
-          
-          s = p;
-          while (*s)
-            {
-              g_string_append_unichar (str, *s);
-              ++s;
-            }
-
-          utf8 = g_string_free (str, FALSE);
-        }
-      else
-        {
-          utf8 = g_locale_to_utf8 (p, -1, NULL, NULL, NULL);
-          /* utf8 will be NULL if the title was not valid
-           * in the locale encoding
-           */
-        }
-      
-      if (utf8)
-        {
-          vt->change_my_name (vt->user_data, utf8, i);
-          g_free (utf8);
-        }
+      /* Order changed to reflect the changed arg. order */
+      vt->change_my_name(vt->user_data, p, i);
     }
   }
 }
@@ -2220,7 +2184,6 @@ int vt_report_button(struct vt_em *vt, int down, int button, int qual, int x, in
 {
   char mouse_info[16];
   int mode = vt->mode & VTMODE_SEND_MOUSE_MASK;
-  static char buttonchar[] = " !\"`abc";
 
   if (y>=0) {
     mouse_info[0]=0;
@@ -2228,13 +2191,13 @@ int vt_report_button(struct vt_em *vt, int down, int button, int qual, int x, in
     case VTMODE_SEND_MOUSE_PRESS: /* press only */
       if (down)
 	g_snprintf(mouse_info, sizeof(mouse_info), "\033[M%c%c%c",
-		   buttonchar[(button - 1)&7],
+		   ' ' + ((button - 1)&3),
 		   x+' '+1,
 		   y+' '+1);
       break;
     case VTMODE_SEND_MOUSE_BOTH:
       g_snprintf(mouse_info, sizeof(mouse_info), "\033[M%c%c%c",
-		 (down?(buttonchar[(button - 1)&7]):(' '+3)) | /* ' ' = lmb, '!' = mid, '"' = rmb, '#' = up, '`' = wheel-down, 'a' = wheel-up */
+		 (down?(' ' + ((button - 1)&3)):(' '+3)) | /* 0 = lmb, 1 = mid, 2 = rmb, 3 = up */
 		 ((qual&1)?4:0) | /* shift */
 		 ((qual&8)?8:0) | /* meta */
 		 ((qual&4)?16:0), /* control */
